﻿using RimWorld;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using UnityEngine;
using Verse;
using Verse.AI;

namespace Koyan
{
    public static class KoyanAIUtility
	{
		public static void GetSmashableThingsNear(Pawn pawn, IntVec3 near, List<Thing> outCandidates, Predicate<Thing> customValidator = null, int extraMinBuildingOrItemMarketValue = 0, int maxDistance = 40)
		{
			outCandidates.Clear();
			if (!pawn.CanReach(near, PathEndMode.OnCell, Danger.Deadly))
			{
				return;
			}
			Region region = near.GetRegion(pawn.Map);
			if (region == null)
			{
				return;
			}
			TraverseParms traverseParams = TraverseParms.For(pawn);
			RegionTraverser.BreadthFirstTraverse(region, (Region from, Region to) => to.Allows(traverseParams, isDestination: false), delegate (Region r)
			{
				List<Thing> list2 = r.ListerThings.ThingsInGroup(ThingRequestGroup.BuildingArtificial);
				for (int j = 0; j < list2.Count; j++)
				{
					if (list2[j].Position.InHorDistOf(near, maxDistance) && TantrumMentalStateUtility.CanSmash(pawn, list2[j], skipReachabilityCheck: true, customValidator, extraMinBuildingOrItemMarketValue))
					{
                        if (list2[j].def.IsBed)
						{
							outCandidates.Add(list2[j]);
						}
                        if (list2[j].def.IsTable)
						{
							outCandidates.Add(list2[j]);
						}
                        if (list2[j].def.IsDoor)
						{
							outCandidates.Add(list2[j]);
						}
					}
				}
				return false;
			}, 40);
		}
	}
}
