﻿using RimWorld;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using UnityEngine;
using Verse;
using Verse.AI;

namespace Koyan
{
    public class MentalState_ScratchStuff : MentalState_Tantrum
	{
		public static List<Thing> tmpThings = new List<Thing>();

		public override void MentalStateTick()
		{
			if (target == null || target.Destroyed)
			{
				RecoverFromState();
			}
			else if (!target.Spawned || !pawn.CanReach(target, PathEndMode.Touch, Danger.Deadly))
			{
				Thing thing = target;
				if (!TryFindNewTarget())
				{
					RecoverFromState();
					return;
				}
				Messages.Message("MessageTargetedTantrumChangedTarget".Translate(pawn.LabelShort, thing.Label, target.Label, pawn.Named("PAWN"), thing.Named("OLDTARGET"), target.Named("TARGET")).AdjustedFor(pawn), pawn, MessageTypeDefOf.NegativeEvent);
				base.MentalStateTick();
			}
			else
			{
				base.MentalStateTick();
			}
		}

		public override void PreStart()
		{
			base.PreStart();
			TryFindNewTarget();
		}

		public bool TryFindNewTarget()
        {
            KoyanAIUtility.GetSmashableThingsNear(pawn, pawn.Position, tmpThings, null);
            bool result = tmpThings.TryRandomElementByWeight((Thing x) => x.MarketValue * (float)x.stackCount, out target);
            tmpThings.Clear();
            return result;
		}

		public override TaggedString GetBeginLetterText()
		{
			if (target == null)
			{
				Log.Error("No target. This should have been checked in this mental state's worker.");
				return "";
			}
			return def.beginLetter.Formatted(pawn.NameShortColored, target.Label, pawn.Named("PAWN"), target.Named("TARGET")).AdjustedFor(pawn).Resolve().CapitalizeFirst();
		}
	}
}
